@@ -2,6 +2,12 @@ from ..curve_data import _tpl_curve_data
 
 
 class _tpl_curve_generator:
+  _identifiers = (
+    "xy",
+    "only points",
+    "scatter"
+  )
+
   def __init__(self, c: _tpl_curve_data):
     self.curve = c
 
