@@ -2,6 +2,13 @@ from .curve_generator import _tpl_curve_generator
 
 
 class _tpl_curve_generator_ybar(_tpl_curve_generator):
+  _identifiers = (
+    "bar",
+    "ybar",
+    "hist",
+    "histogram"
+  )
+
   def _get_fill(self):
     color = "=%s" % self.curve.color.get_value() if self.curve.color.get_value() is not None else ""
     return "fill%s,\n  fill opacity=0.3," % color
@@ -24,5 +31,10 @@ class _tpl_curve_generator_ybar(_tpl_curve_generator):
 
 
 class _tpl_curve_generator_ybarinterval(_tpl_curve_generator_ybar):
+  _identifiers = (
+    "interval",
+    "ybar interval"
+  )
+
   def _get_type(self):
       return "ybar interval,"
